@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -249,7 +249,7 @@ bool IPv4Address::operator!=(const IPAddress& p_addr) const
   return !(*this == p_addr);
 }
 
-IPAddress& IPv4Address::operator=(const IPAddress& p_addr)
+IPv4Address& IPv4Address::operator=(const IPAddress& p_addr)
 {
   clean_up();
   memcpy(&m_addr, &(static_cast<const IPv4Address&>(p_addr)).m_addr, sizeof(m_addr));
@@ -390,7 +390,7 @@ bool IPv6Address::operator!=(const IPAddress& p_addr) const
   return !(*this == p_addr);
 }
 
-IPAddress& IPv6Address::operator=(const IPAddress& p_addr)
+IPv6Address& IPv6Address::operator=(const IPAddress& p_addr)
 {
   clean_up();
   memcpy(&m_addr, &(static_cast<const IPv6Address&>(p_addr)).m_addr, sizeof(m_addr));
