@@ -431,6 +431,7 @@ void QuadSet::add(QuadInterval* interval) {
         if (it == set)
           set = it->next;
         quadset_node_t* p = it;
+        it_old->next = it->next;
         it = it->next;
         delete p;
         continue;
@@ -571,7 +572,7 @@ void QuadSet::do_negate() {
     case QSET_QUAD:
       q2 = it->u.p_quad->get_value() - 1;
       qs->add_negate_interval(q1, q2);
-      q1 = q2.get_value() + 1;
+      q1 = it->u.p_quad->get_value() + 1;
       break;
     case QSET_INTERVAL:
       q2 = it->u.p_interval->get_lower().get_value() - 1;
