@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -39,6 +39,7 @@
 #include "ttcn3/profiler.h"
 #include "ttcn3/Attributes.hh"
 #include "ttcn3/Ttcnstuff.hh"
+#include "ttcn3/Statement.hh"
 
 namespace Common {
 
@@ -77,7 +78,7 @@ namespace Common {
     yyloc.last_column = 0;
   }
 
-  void Location::set_location(const char *p_filename, int p_lineno)
+  void Location::set_location(const char *p_filename, size_t p_lineno)
   {
     filename = p_filename;
     yyloc.first_line = p_lineno;
@@ -102,8 +103,8 @@ namespace Common {
     yyloc.last_column = p_lastloc.last_column;
   }
 
-  void Location::set_location(const char *p_filename, int p_first_line,
-    int p_first_column, int p_last_line, int p_last_column)
+  void Location::set_location(const char *p_filename, size_t p_first_line,
+    size_t p_first_column, size_t p_last_line, size_t p_last_column)
   {
     filename = p_filename;
     yyloc.first_line = p_first_line;
@@ -141,51 +142,51 @@ namespace Common {
       if (output_only_linenum || (yyloc.first_line == yyloc.last_line &&
           yyloc.first_column <= 0 && yyloc.last_column <= 0)) {
 	// print only the first line
-	fprintf(fp, "%d", yyloc.first_line);
+	fprintf(fp, "%lu", yyloc.first_line);
       } else if (yyloc.last_line > yyloc.first_line) {
 	// multi-line area
 	if (yyloc.first_column >= 0 && yyloc.last_column >= 0) {
 	  // all line/column fields are valid
 	  if (gcc_compat) {
-	    fprintf(fp, "%d:%d", yyloc.first_line, yyloc.first_column + 1);
+	    fprintf(fp, "%lu:%lu", yyloc.first_line, yyloc.first_column + 1);
 	  }
 	  else {
-	    fprintf(fp, "%d.%d-%d.%d", yyloc.first_line,
+	    fprintf(fp, "%lu.%lu-%lu.%lu", yyloc.first_line,
 	      yyloc.first_column + 1, yyloc.last_line, yyloc.last_column);
 	  }
 	} else {
 	  // only the line numbers are valid
 	  if (gcc_compat) {
-	    fprintf(fp, "%d", yyloc.first_line);
+	    fprintf(fp, "%lu", yyloc.first_line);
 	  }
 	  else {
-	    fprintf(fp, "%d-%d", yyloc.first_line, yyloc.last_line);
+	    fprintf(fp, "%lu-%lu", yyloc.first_line, yyloc.last_line);
 	  }
 	}
       } else if (yyloc.first_line == yyloc.last_line) {
 	// single line area
 	if (yyloc.first_column >= 0 && yyloc.last_column > yyloc.first_column) {
 	  if (gcc_compat) {
-	    fprintf(fp, "%d:%d", yyloc.first_line, yyloc.first_column + 1);
+	    fprintf(fp, "%lu:%lu", yyloc.first_line, yyloc.first_column + 1);
 	  }
 	  else {
 	    if (yyloc.last_column > yyloc.first_column + 1) {
 	      // more characters are covered
-	      fprintf(fp, "%d.%d-%d", yyloc.first_line, yyloc.first_column + 1,
+	      fprintf(fp, "%lu.%lu-%lu", yyloc.first_line, yyloc.first_column + 1,
 	        yyloc.last_column);
 	    } else {
 	      // only a single character is covered
-	      fprintf(fp, "%d.%d", yyloc.first_line, yyloc.first_column + 1);
+	      fprintf(fp, "%lu.%lu", yyloc.first_line, yyloc.first_column + 1);
 	    }
 	  }
 	} else {
 	  // the column information is invalid, print the line number only
-	  fprintf(fp, "%d", yyloc.first_line);
+	  fprintf(fp, "%lu", yyloc.first_line);
 	}
       } else {
 	// the last line is smaller than the first line
 	// print only the first line
-	fprintf(fp, "%d", yyloc.first_line);
+	fprintf(fp, "%lu", yyloc.first_line);
       }
     } else {
       // line information is not available
@@ -243,11 +244,11 @@ namespace Common {
         		      : "TTCN_Location_Statistics current_location(\"");
       str = Code::translate_string(str, filename);
       str = mputprintf(str,
-        !tcov_enabled ? "\", %d, TTCN_Location::LOCATION_%s, \"%s\");\n"
-        		      : "\", %d, TTCN_Location_Statistics::LOCATION_%s, \"%s\");\n", yyloc.first_line, entitytype, entityname);
+        !tcov_enabled ? "\", %lu, TTCN_Location::LOCATION_%s, \"%s\");\n"
+        		      : "\", %lu, TTCN_Location_Statistics::LOCATION_%s, \"%s\");\n", yyloc.first_line, entitytype, entityname);
       if (tcov_enabled) {
           effective_module_lines =
-            mputprintf(effective_module_lines, "%s%d",
+            mputprintf(effective_module_lines, "%s%lu",
             		   (effective_module_lines ? ", " : ""), yyloc.first_line);
           effective_module_functions =
             mputprintf(effective_module_functions, "%s\"%s\"",
@@ -262,7 +263,7 @@ namespace Common {
         char* file_name2 = mcopystrn(filename, file_name_len);
         str = mputprintf(str,
           "TTCN3_Stack_Depth stack_depth;\n"
-          "ttcn3_prof.enter_function(\"%s\", %d);\n", file_name2, yyloc.first_line);
+          "ttcn3_prof.enter_function(\"%s\", %lu);\n", file_name2, yyloc.first_line);
         insert_profiler_code_line(file_name2, 
           (0 == strcmp(entitytype, "CONTROLPART") ? "control" : entityname),
           yyloc.first_line);
@@ -276,7 +277,7 @@ namespace Common {
   {
     if (filename && yyloc.first_line > 0) {
       if (include_location_info && !transparency) {
-        str = mputprintf(str, "current_location.update_lineno(%d);\n",
+        str = mputprintf(str, "current_location.update_lineno(%lu);\n",
                          yyloc.first_line);
         const char* file_name = get_filename();
         if (is_file_profiled(file_name)) {
@@ -286,24 +287,24 @@ namespace Common {
             file_name_len -= 2;
           }
           char* file_name2 = mcopystrn(file_name, file_name_len);
-          str = mputprintf(str, "ttcn3_prof.execute_line(\"%s\", %d);\n",
+          str = mputprintf(str, "ttcn3_prof.execute_line(\"%s\", %lu);\n",
                   file_name2, yyloc.first_line);
           insert_profiler_code_line(file_name2, NULL, yyloc.first_line);
           Free(file_name2);
         }
         if (tcov_file_name && in_tcov_files(file_name)) {
             effective_module_lines =
-              mputprintf(effective_module_lines, "%s%d",
+              mputprintf(effective_module_lines, "%s%lu",
               		   (effective_module_lines ? ", " : ""), yyloc.first_line);
         }
         if (debugger_active) {
-          str = mputprintf(str, "ttcn3_debugger.breakpoint_entry(%d);\n", yyloc.first_line);
+          str = mputprintf(str, "ttcn3_debugger.breakpoint_entry(%lu);\n", yyloc.first_line);
         }
       }
 
       if (include_line_info)
-        str = mputprintf(str, "#line %d \"%s\"\n", yyloc.first_line, filename);
-      else str = mputprintf(str, "/* %s, line %d */\n", filename,
+        str = mputprintf(str, "#line %lu \"%s\"\n", yyloc.first_line, filename);
+      else str = mputprintf(str, "/* %s, line %lu */\n", filename,
                             yyloc.first_line);
     }
     return str;
@@ -606,7 +607,7 @@ namespace Common {
     return 0;
   }
   
-  const Ttcn::ClassTypeBody* Scope::get_scope_class() const
+  Ttcn::ClassTypeBody* Scope::get_scope_class()
   {
     if (parent_scope != NULL) {
       return parent_scope->get_scope_class();
@@ -676,6 +677,9 @@ namespace Common {
     case Type::T_ALTSTEP:
       typetype_name = "altstep";
       break;
+    case Type::T_CLASS:
+      typetype_name = "class";
+      break;
     default:
       FATAL_ERROR("Scope::chk_runs_on_clause()");
       typetype_name = 0;
@@ -727,6 +731,33 @@ namespace Common {
     }
   }
   
+  void Scope::chk_mtc_clause(Type* p_type, const Location& p_loc)
+  {
+    // component type of the referred definition
+    Type* refd_comptype = p_type->get_class_type_body()->get_MtcType();
+    // definitions without 'mtc' can be called from anywhere
+    if (refd_comptype == NULL) {
+      return;
+    }
+    if (get_statementblock_scope()->get_my_def() == NULL) { // in control part
+      p_loc.error("Cannot create value of class type `%s', which has an `mtc' "
+        "clause, in the control part.", p_type->get_typename().c_str());
+      return;
+    }
+    Type* t_comptype = get_mtc_system_comptype(false);
+    if (t_comptype != NULL) {
+      if (!refd_comptype->is_compatible_component_by_port(t_comptype)) {
+        // the 'mtc' clause of the referred definition is not compatible
+        // with that of the current scope (i.e. the referring definition)
+        p_loc.error("Mtc clause mismatch: A definition that runs on component "
+          "type `%s' cannot create a value of class type `%s', which has `mtc' "
+          "component type `%s'",
+          t_comptype->get_typename().c_str(), p_type->get_typename().c_str(),
+          refd_comptype->get_typename().c_str());
+      }
+    }
+  }
+  
   void Scope::chk_system_clause(Assignment *p_ass, const Location& p_loc,
     const char *p_what, bool in_control_part)
   {
@@ -751,6 +782,33 @@ namespace Common {
       }
     }
   }
+  
+  void Scope::chk_system_clause(Type* p_type, const Location& p_loc)
+  {
+    // component type of the referred definition
+    Type* refd_comptype = p_type->get_class_type_body()->get_SystemType();
+    // definitions without 'system' can be called from anywhere
+    if (refd_comptype == NULL) {
+      return;
+    }
+    if (get_statementblock_scope()->get_my_def() == NULL) { // in control part
+      p_loc.error("Cannot create value of class type `%s', which has a `system' "
+        "clause, in the control part.", p_type->get_typename().c_str());
+      return;
+    }
+    Type* t_comptype = get_mtc_system_comptype(true);
+    if (t_comptype != NULL) {
+      if (!refd_comptype->is_compatible_component_by_port(t_comptype)) {
+        // the 'system' clause of the referred definition is not compatible
+        // with that of the current scope (i.e. the referring definition)
+        p_loc.error("System clause mismatch: A definition that runs on component "
+          "type `%s' cannot create a value of class type `%s', which has `system' "
+          "component type `%s'",
+          t_comptype->get_typename().c_str(), p_type->get_typename().c_str(),
+          refd_comptype->get_typename().c_str());
+      }
+    }
+  }
 
   // =================================
   // ===== Reference
@@ -797,6 +855,11 @@ namespace Common {
   void Reference::set_code_section(GovernedSimple::code_section_t)
   {
   }
+  
+  Assignment* Reference::get_refd_assignment_last(bool check_parlist)
+  {
+    return this->get_refd_assignment(check_parlist);
+  }
 
   Ttcn::FieldOrArrayRefs *Reference::get_subrefs()
   {
@@ -938,8 +1001,8 @@ namespace Common {
     if (errors.size() < *err_stack.top())
       FATAL_ERROR("Common::ReferenceChain::prev_error_state()");
 
-    int state = static_cast<int>(*err_stack.top());
-    for (int i = static_cast<int>(errors.size()) - 1; i >= state; --i) {
+    int state =  static_cast<int>(*err_stack.top());
+    for (int i =  static_cast<int>(errors.size()) - 1; i >= state; --i) {
       errors.remove(i);
     }
     delete err_stack.pop();
