@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -27,7 +27,7 @@ extern int asn1_yylex();
 extern const char *asn1_infile;
 extern int asn1_yylineno;
 #define yylineno asn1_yylineno
-extern int asn1_plineno;
+extern size_t asn1_plineno;
 #define plineno asn1_plineno
 extern YYLTYPE asn1_yylloc;
 #define yylloc asn1_yylloc
