@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -1023,13 +1023,13 @@ namespace Ttcn {
 
   ParsedActualParameters::ParsedActualParameters(TemplateInstances *p_ti,
                                                  NamedParams *p_np)
-  : Node(), Location(), unnamedpart(p_ti ? p_ti : new TemplateInstances), namedpart(p_np)
+  : Node(), Location(), unnamedpart(p_ti ? p_ti : new TemplateInstances), namedpart(p_np), my_scope(NULL)
   {
   }
 
   ParsedActualParameters::ParsedActualParameters(const ParsedActualParameters& p)
   : Node(p), Location(p), unnamedpart(p.unnamedpart->clone()),
-    namedpart (p.namedpart ? p.namedpart->clone() : 0)
+    namedpart (p.namedpart ? p.namedpart->clone() : 0), my_scope(p.my_scope)
   {
   }
 
@@ -1067,6 +1067,7 @@ namespace Ttcn {
 
   void ParsedActualParameters::set_my_scope(Common::Scope *p_scope)
   {
+    my_scope = p_scope;
     unnamedpart->set_my_scope(p_scope);
     if (namedpart) {
       namedpart->set_my_scope(p_scope);
@@ -1081,7 +1082,7 @@ namespace Ttcn {
     }
   }
 
-  void ParsedActualParameters::set_location(const char *p_filename, int p_lineno)
+  void ParsedActualParameters::set_location(const char *p_filename, size_t p_lineno)
   {
     Location   ::set_location(p_filename, p_lineno);
     if (namedpart)
@@ -1108,8 +1109,8 @@ namespace Ttcn {
     unnamedpart->set_location(p_filename, p_firstloc, p_lastloc);
   }
 
-  void ParsedActualParameters::set_location(const char *p_filename, int p_first_line,
-    int p_first_column, int p_last_line, int p_last_column)
+  void ParsedActualParameters::set_location(const char *p_filename, size_t p_first_line,
+    size_t p_first_column, size_t p_last_line, size_t p_last_column)
   {
     Location   ::set_location(p_filename, p_first_line, p_first_column,
                                           p_last_line, p_last_column);
