@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -680,7 +680,7 @@ void BITSTRING::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
       TTCN_EncDec_ErrorContext::error_internal
         ("No JSON descriptor available for type '%s'.", p_td.name);
     JSON_Tokenizer tok(va_arg(pvar, int) != 0);
-    JSON_encode(p_td, tok);
+    JSON_encode(p_td, tok, FALSE);
     p_buf.put_s(tok.get_buffer_length(), (const unsigned char*)tok.get_buffer());
     break;}
   case TTCN_EncDec::CT_OER: {
@@ -750,7 +750,7 @@ void BITSTRING::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
       TTCN_EncDec_ErrorContext::error_internal
         ("No JSON descriptor available for type '%s'.", p_td.name);
     JSON_Tokenizer tok((const char*)p_buf.get_data(), p_buf.get_len());
-    if(JSON_decode(p_td, tok, FALSE)<0)
+    if(JSON_decode(p_td, tok, FALSE, FALSE)<0)
       ec.error(TTCN_EncDec::ET_INCOMPL_MSG,
                "Can not decode type '%s', because invalid or incomplete"
                " message was received"
@@ -1011,12 +1011,10 @@ int BITSTRING::RAW_encode(const TTCN_Typedescriptor_t& p_td, RAW_enc_tree& mylea
   myleaf.must_free = FALSE;
   myleaf.data_ptr_used = TRUE;
   myleaf.body.leaf.data_ptr = val_ptr->bits_ptr;
-  boolean orders = FALSE;
-  if (p_td.raw->byteorder       == ORDER_MSB) orders = TRUE;
+  boolean orders = p_td.raw->byteorder == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_LSB) orders = !orders;
   myleaf.coding_par.byteorder = orders ? ORDER_MSB : ORDER_LSB;
-  orders = FALSE;
-  if (p_td.raw->bitorderinoctet == ORDER_MSB) orders = TRUE;
+  orders = p_td.raw->bitorderinoctet == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_LSB) orders = !orders;
   myleaf.coding_par.bitorder = orders ? ORDER_MSB : ORDER_LSB;
   myleaf.coding_par.csn1lh = p_td.raw->csn1lh;
@@ -1046,12 +1044,10 @@ int BITSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
   clean_up();
   init_struct(decode_length);
   RAW_coding_par cp;
-  boolean orders = FALSE;
-  if (p_td.raw->bitorderinoctet == ORDER_MSB) orders = TRUE;
+  boolean orders = p_td.raw->bitorderinoctet == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_LSB) orders = !orders;
   cp.bitorder = orders ? ORDER_MSB : ORDER_LSB;
-  orders = FALSE;
-  if (p_td.raw->byteorder == ORDER_MSB) orders = TRUE;
+  orders = p_td.raw->byteorder == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_LSB) orders = !orders;
   cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
   cp.fieldorder = p_td.raw->fieldorder;
@@ -1181,7 +1177,7 @@ int BITSTRING::XER_decode(const XERdescriptor_t& p_td, XmlReaderWrap& reader,
   return 1;
 }
 
-int BITSTRING::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok) const
+int BITSTRING::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok, boolean) const
 {
   if (!is_bound()) {
     TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,
@@ -1201,7 +1197,7 @@ int BITSTRING::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok)
   return enc_len;
 }
 
-int BITSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent, int)
+int BITSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent, boolean, int)
 {
   json_token_t token = JSON_TOKEN_NONE;
   char* value = 0;
@@ -1248,6 +1244,7 @@ int BITSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_
         }
       }
       if (!error) {
+        clean_up();
         init_struct(bits);
         int bit_index = 0;
         for (size_t i = 0; i < value_len; ++i) {
@@ -1256,6 +1253,7 @@ int BITSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_
             ++bit_index;
           }
         }
+        clear_unused_bits();
       }
     } else {
       error = TRUE;
