@@ -860,7 +860,10 @@ void TTCN_Communication::send_create_req(const char *component_type_module,
   text_buf.push_string(component_name);
   text_buf.push_string(component_location);
   text_buf.push_int(is_alive ? 1 : 0);
-  text_buf.push_int(testcase_start_time.tv_sec);
+  int upper_int = testcase_start_time.tv_sec / 0xffffffff;
+  int lower_int = testcase_start_time.tv_sec % 0xffffffff;
+  text_buf.push_int(upper_int);
+  text_buf.push_int(lower_int);
   text_buf.push_int(testcase_start_time.tv_usec);
   send_message(text_buf);
 }
@@ -1235,7 +1238,10 @@ boolean TTCN_Communication::send_log(time_t timestamp_sec, long timestamp_usec,
   if (is_connected) {
     Text_Buf text_buf;
     text_buf.push_int(MSG_LOG);
-    text_buf.push_int(timestamp_sec);
+    int upper_int = timestamp_sec / 0xffffffff;
+    int lower_int = timestamp_sec % 0xffffffff;
+    text_buf.push_int(upper_int);
+    text_buf.push_int(lower_int);
     text_buf.push_int(timestamp_usec);
     text_buf.push_int(event_severity);
     text_buf.push_int(message_text_len);
@@ -1402,7 +1408,9 @@ void TTCN_Communication::process_create_ptc()
   qualified_name current_testcase;
   incoming_buf.pull_qualified_name(current_testcase);
   timeval testcase_start_time;
-  testcase_start_time.tv_sec = incoming_buf.pull_int().get_val();
+  int upper_int = incoming_buf.pull_int().get_val();
+  int lower_int = incoming_buf.pull_int().get_val();
+  testcase_start_time.tv_sec = upper_int * 0xffffffff + lower_int;
   testcase_start_time.tv_usec = incoming_buf.pull_int().get_val();
   incoming_buf.cut_message();
 
