@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -88,8 +88,6 @@ struct TTCN_Logger::log_mask_struct
 
 /** @} */
 
-class LogEventType;
-
 /* Static members */
 
 LoggerPluginManager *TTCN_Logger::plugins_ = NULL;
@@ -458,6 +456,10 @@ char *TTCN_Logger::mputstr_timestamp(char *str,
     time_t tv_sec = tv->tv_sec;
     struct tm *lt = localtime(&tv_sec);
     if (lt == NULL) fatal_error("localtime() call failed.");
+    // HACK: 'localtime' may set the 'errno' on some systems (even though it
+    // succeeds)
+    // reset it, so it doesn't affect other code
+    errno = 0;
     if (p_timestamp_format == TIMESTAMP_TIME) {
       str = mputprintf(str, "%02d:%02d:%02d.%06ld",
                        lt->tm_hour, lt->tm_min, lt->tm_sec, tv->tv_usec);
