@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -83,7 +83,7 @@ void JUnitLogger2::set_parameter(const char *parameter_name, const char *paramet
       Free(filename_stem_);
     filename_stem_ = mcopystr(parameter_value);
   } else if (!strcmp("testsuite_name", parameter_name)) {
-    if (filename_stem_ != NULL)
+    if (testsuite_name_ != NULL)
       Free(testsuite_name_);
     testsuite_name_ = mcopystr(parameter_value);
   } else {
@@ -236,13 +236,6 @@ void TestCase::writeTestCase(FILE* file_stream_) const{
       fprintf(file_stream_, "    <error type='DTE'>%s</error>\n", dte_reason.data());
       fprintf(file_stream_, "  </testcase>\n");
       break; }
-    case Inconc:  {
-      fprintf(file_stream_, "  <testcase classname='%s' name='%s' time='%f'>\n", module_name.data(), tc_name.data(), time);
-      fprintf(file_stream_, "    <failure type='inconclusive-verdict'>%s\n", reason.data());
-      fprintf(file_stream_, "%s\n", stack_trace.data());
-      fprintf(file_stream_, "    </failure>\n");
-      fprintf(file_stream_, "  </testcase>\n");
-      break; }
     default: 
       fprintf(file_stream_, "  <testcase classname='%s' name='%s' time='%f'/>\n", module_name.data(), tc_name.data(), time);
       break;
