@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -1109,7 +1109,7 @@ void PatternType::applyFacet() // only for time types and string types without h
         {
           if (charclass == 0) {
             Mstring s;
-            int k = 1;
+            size_t k = 1;
             while (facet[i + k] != '}') {
               s += facet[i + k];
               ++k;
@@ -1195,7 +1195,7 @@ void PatternType::applyFacet() // only for time types and string types without h
         case '&':
           if (facet[i + 1] == '#') { // &#....;
             Mstring s;
-            int k = 2;
+            size_t k = 2;
             while (facet[i + k] != ';') {
               s += facet[i + k];
               ++k;
